@@ -1295,6 +1295,8 @@ perturb_vertex( PVertex pv
               , bool *could_lock_zone
               ) const
 {
+  typename Gt::Construct_point_3 wp2p = tr_.geom_traits().construct_point_3_object();
+
 #ifdef CGAL_CONCURRENT_MESH_3_PROFILING
   static Profile_branch_counter_3 bcounter(
     "early withdrawals / late withdrawals / successes [Perturber]");
@@ -1307,9 +1309,10 @@ perturb_vertex( PVertex pv
   {
     return;
   }
-  
-  Point_3 p = pv.vertex()->point();
-  if (!helper_.try_lock_point_no_spin(p) || ! Gt().equal_3_object()(p,pv.vertex()->point()))
+
+  Point_3 p = wp2p(pv.vertex()->point());
+  if (!helper_.try_lock_point_no_spin(pv.vertex()->point()) ||
+      ! tr_.geom_traits().equal_3_object()(p, wp2p(pv.vertex()->point())))
   {
 #ifdef CGAL_CONCURRENT_MESH_3_PROFILING
     bcounter.increment_branch_2(); // THIS is an early withdrawal!
